# :nodoc:
#
# Author:: Nathaniel Talbott.
# Copyright:: Copyright (c) 2000-2002 Nathaniel Talbott. All rights reserved.
# License:: Ruby license.

require 'test/unit/ui/testrunnermediator'
require 'test/unit/ui/testrunnerutilities'

module Test
	module Unit
		module UI
			module Console # :nodoc:

				# Runs a Test::Unit::TestSuite on the console.
				class TestRunner
					extend TestRunnerUtilities

					# Creates a new TestRunner and runs the suite.
					def TestRunner.run(suite)
						return new(suite).start
					end

					# Creates a new TestRunner for running the passed
					# suite. If quiet_mode is true, the output while
					# running is limited to progress dots, errors and
					# failures, and the final result. io specifies
					# where runner output should go to; defaults to
					# STDERR.
					def initialize(suite, quiet_mode=false, io=STDERR)
						if (suite.respond_to?(:suite))
							@suite = suite.suite
						else
							@suite = suite
						end
						@quiet_mode = quiet_mode
						@io = io
						@result = TestResult.new
					end

					# Begins the test run.
					def start
						setup_mediator
						attach_to_mediator
						return start_mediator
					end

					private
					def setup_mediator # :nodoc:
						@mediator = create_mediator(@suite)
						suite_name = @suite.to_s
						if ( @suite.kind_of?(Module) )
							suite_name = @suite.name
						end
						@io.puts("Loaded suite #{suite_name}") if (!@quiet_mode)
					end
					def create_mediator(suite) # :nodoc:
						return TestRunnerMediator.new(suite)
					end
					def attach_to_mediator # :nodoc:
						@mediator.add_listener(TestRunnerMediator::FAULT_ADDED, &method(:add_fault))
						@mediator.add_listener(TestRunnerMediator::RESULT_CHANGED, &method(:result_changed))
						@mediator.add_listener(TestRunnerMediator::STATUS_CHANGED, &method(:update_status))
					end
					def start_mediator # :nodoc:
						return @mediator.run_suite
					end
					def add_fault(fault) # :nodoc:
						@io.puts
						@io.puts(fault.long_display)
					end
					def result_changed(result) # :nodoc:
						@result = result
					end
					def update_status(status) # :nodoc:
						if ( status.type == Status::STARTED_RUNNING )
							@io.puts( status.message ) if (!@quiet_mode)
						elsif ( status.type == Status::FINISHED_TEST )
							@io.write(".")
						elsif ( status.type == Status::FINISHED_RUNNING )
							@io.puts
							@io.puts( status.message ) if (!@quiet_mode)
							@io.puts( @result )
						end
					end
				end
			end
		end
	end
end

if __FILE__ == $0
	Test::Unit::UI::Console::TestRunner.start_command_line_test
end
